/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2007-2008. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *******************************************************************************/
(function() {

dojo.provide("com.ibm.rational.report.web.core.app.view.admin.ViewGroupViewer");

dojo.require("dijit._Widget");
dojo.require("dijit._Templated");
dojo.require("com.ibm.rational.report.web.core.client.internal.UserClient");
dojo.require("com.ibm.rational.report.web.core.app.internal.common.SelectionWidget");
dojo.require("com.ibm.rational.report.web.core.app.internal.MessageFormatter");
dojo.require("com.ibm.team.repository.web.transport.ServiceResponseHandler");
dojo.requireLocalization("com.ibm.rational.report.web.core.app.serviceability", "Messages");
dojo.requireLocalization("com.ibm.rational.report.web.core.app.view.admin", "Messages");

var ServiceabilityMessages	= dojo.i18n.getLocalization("com.ibm.rational.report.web.core.app.serviceability", "Messages");
var CoreAdminMessages		= dojo.i18n.getLocalization("com.ibm.rational.report.web.core.app.view.admin", "Messages");
var UserClient				= com.ibm.rational.report.web.core.client.internal.UserClient;
var MessageFormatter		= com.ibm.rational.report.web.core.app.internal.MessageFormatter;
var ServiceResponseHandler 	= com.ibm.team.repository.web.transport.ServiceResponseHandler;

/**
 * Displays the Edit Group view.
 */
dojo.declare(
	"com.ibm.rational.report.web.core.app.view.admin.ViewGroupViewer",
	[dijit._Widget, dijit._Templated],	{
	
	templatePath: dojo.moduleUrl("com.ibm.rational.report.web.core", "app/view/admin/templates/ViewGroupViewer.html"),
	
	constructor: function(args) {
		this._controller = args.controller;
		this.groupName.value = args.groupName;
	},
	
	postCreate: function() {			
		this._members = [];
		this._users = [];
		this._selectionWidget = null;
		this._msgFormatter = new MessageFormatter(this.messageArea);
		
		var self = this;
				
		dojo.connect(this.closeButton, "onclick",
			function(e) {
				e.preventDefault();
				self._controller.manageUsers();
			}
		);
			
		var responseHandler = new ServiceResponseHandler(this, "_listMembers", "_getGroupError");
		UserClient.getGroup(responseHandler, {name: this.groupName.value});
	},
	
	_listMembers: function(group) {	
		var members = group.members;
		if (typeof members != "undefined" && members != null && members.length > 0) {
			members.sort();
			this._members = members;
		}
		else {
			this._members = [];
		}
		this._getAllUsers();
	},
	
	_getGroupError: function(error) {
		this._msgFormatter.displayErrorMessage(ServiceabilityMessages.FAILED_TO_RETRIEVE_GROUPS, error);
	},
	
	_getAllUsers: function() {
		var responseHandler = new ServiceResponseHandler(this, "_listUsers", "_getAllUsersError");
		UserClient.getAllUsers(responseHandler);		
	},
	
	_listUsers: function(users) {
		this._users = [];
		if (users != null && users.length > 0) {
			var members = this._members;
			for (var i = 0; i < users.length; i++) {
				var user = users[i];
				if (user != this.groupName.value && (members == null || this._isMember(members, user) == false)) {
					this._users.push(user);
				}
			}
		}
		this._createSelectionWidget();
	},
		
	_getAllUsersError: function(error) {
		this._msgFormatter.displayErrorMessage(ServiceabilityMessages.FAILED_TO_RETRIEVE_USERS, error);
	},
	
	_createSelectionWidget: function() {
		this._msgFormatter.displayNoMessage();			
		
		var availableOptions = [];
		var selectedOptions = [];

		if (this._users != null) {
			for (var i = 0; i < this._users.length; i++ ) {
				var user = this._users[i];
				availableOptions.push({value: user.name, text: user.name});
			}
		}
					
		if (this._members != null) {
			for (var i = 0; i < this._members.length; i++ ) {
				var user = this._members[i];
				selectedOptions.push({value: user.name, text: user.name});
			}	
		}
		
		/*
		this._selectionWidget = new com.ibm.rational.report.web.core.app.internal.common.SelectionWidget(
			{availableOptions: availableOptions, selectedOptions: selectedOptions,
			 availableItemsTitle: "Available Users:", selectedItemsTitle: "Group Members:", readOnly: true});
		*/
		this._selectionWidget = new com.ibm.rational.report.web.core.app.internal.common.SelectionWidget(
			{availableOptions: availableOptions, selectedOptions: selectedOptions,
			 availableItemsTitle: CoreAdminMessages.EDITGROUP_VIEWER_AVAILABLE_USERS_LABEL, selectedItemsTitle: CoreAdminMessages.EDITGROUP_VIEWER_GROUP_MEMBERS_LABEL, readOnly: true});
			 
		this.userGroupSelections.appendChild(this._selectionWidget.domNode);
		
	},
	
	_isMember: function(members, user) {
		for (var i = 0; i < members.length; i++) {
			var member = members[i];
			if (member.name == user.name) {
				return true;
			}
		}
		return false;
	}
	
});

})();