/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2007-2008. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *******************************************************************************/
(function() {

dojo.provide("com.ibm.rational.report.web.core.app.view.report.SelectRecipentsDialog");

dojo.require("dijit._Widget");
dojo.require("dijit._Templated");
dojo.require("dojox.data.dom");
dojo.require("net.jazz.ajax.ui.internal.Dialog");
dojo.require("com.ibm.rational.report.web.core.client.internal.UserClient");
dojo.require("com.ibm.rational.report.web.core.app.internal.MessageFormatter");
dojo.require("com.ibm.rational.report.web.core.app.internal.common.SelectionWidget");
dojo.require("com.ibm.team.repository.web.client.session.Session");
dojo.require("com.ibm.rational.report.web.core.app.internal.common.CommonDialog");
dojo.require("com.ibm.team.repository.web.transport.ServiceResponseHandler");
dojo.requireLocalization("com.ibm.rational.report.web.core.app.internal.common", "Messages");
dojo.requireLocalization("com.ibm.rational.report.web.core.app.serviceability", "Messages");
dojo.requireLocalization("com.ibm.rational.report.web.core.app.view.report", "Messages");

var CommonMessages	    	= dojo.i18n.getLocalization("com.ibm.rational.report.web.core.app.internal.common", "Messages");
var ServiceabilityMessages	= dojo.i18n.getLocalization("com.ibm.rational.report.web.core.app.serviceability", "Messages");
var ReportMessages			= dojo.i18n.getLocalization("com.ibm.rational.report.web.core.app.view.report", "Messages");
var UserClient 				= com.ibm.rational.report.web.core.client.internal.UserClient;
var MessageFormatter		= com.ibm.rational.report.web.core.app.internal.MessageFormatter;
var session					= com.ibm.team.repository.web.client.session;
var ServiceResponseHandler 	= com.ibm.team.repository.web.transport.ServiceResponseHandler;
var count =1;
/**
 * Displays the Select Users and Teams view.
 */
dojo.declare(
	"com.ibm.rational.report.web.core.app.view.report.SelectRecipentsDialog",
	[dijit._Widget, dijit._Templated],	{
	
	templatePath: dojo.moduleUrl("com.ibm.rational.report.web.core", "app/view/report/templates/SelectRecipentsDialog.html"),
	
	constructor: function(args) {
		this._availableTitle = args.availableTitle;
		this._control = args.control;
		this._selectedTitle = args.selectedTitle;
	},
	
	postCreate: function() {	
		this._initText();
		
		this._msgFormatter = new MessageFormatter(this.messageArea);
		this._selWidget = null;
		
		this._loadAvailableGroups();
		
		// TODO: This does not work
		var self = this;
		dojo.connect(this.contentNode, "onkeypress", 
			function(e) {
				if (e.keyCode == dojo.keys.ESCAPE) {
					self.close();
				}
			}
		);		
		
		this.dialog = new com.ibm.rational.report.web.core.app.internal.common.CommonDialog({
			contentNode: this.contentNode,
			primaryTitle: ReportMessages.EMAIL_REPORT_VIEWER_SELECT_EMAIL_RECIPENTS_LABEL,
			width: "394px",
			isClosable: true
		});
		
		dojo.connect(this.dialog._close, "onclick", 
			function(e){
				self.blockerDiv.parentNode.removeChild(self.blockerDiv);
				count--;
			});
			
		this.closeButton.focus();
		
		//add a div for the background whose z-index is more than the previous dialog
		//also increase the z-index of the current dialog, so that it always remains on top.
		this.dialog.domNode.style.zIndex = 10001+(count*2);
		this.dialog.blockerDiv.parentNode.removeChild(this.dialog.blockerDiv);
		this.blockerDiv = document.createElement("div");
		this.blockerDiv.className = "net-jazz-ajax-ui-internal-Dialog-blockerDiv";
		this.blockerDiv.style.height = document.body.offsetHeight + "px";
		this.blockerDiv.style.top = document.documentElement.scrollTop + "px";
		this.blockerDiv.style.left = document.documentElement.scrollLeft + "px";
		this.blockerDiv.style.zIndex = 10000 + (count*2);
		if(dojo.isIE)
			this.blockerDiv.style.display = "block";
		document.body.appendChild(this.blockerDiv);
		count++;
	},
	
	_initText: function() {
		dojox.data.dom.removeChildren(this.saveButton);
		this.saveButton.appendChild(document.createTextNode(CommonMessages.SAVE_BUTTON_LABEL));
		
		dojox.data.dom.removeChildren(this.closeButton);
		this.closeButton.appendChild(document.createTextNode(CommonMessages.CLOSE_BUTTON_LABEL));		
	},	
	
	_loadAvailableGroups: function() {		
		var srh = new ServiceResponseHandler(this, "_loadAvailableUsers", "_getAllGroupsError");	
		UserClient.getAllGroups(srh);
	},
	
	_loadAvailableUsers: function(result) {	
		this._groups = result;	
		var srh = new ServiceResponseHandler(this, "_fillUserGroupControlData",	"_getAllUsersError");	
		UserClient.getAllUsers(srh, {excludeJazzAdmin: true});
	},
	
	_getAllGroupsError: function(error) {
		this._msgFormatter.displayErrorMessage(ServiceabilityMessages.FAILED_TO_RETRIEVE_GROUPS, error);
	},
	
	_fillUserGroupControlData: function(result) {
		this._users = result;
		
		var controlValue = this._control.value;
		var selectedOptions = [];
		if (controlValue != null) {
			var values = controlValue.split(",");
			for (var i = 0; i < values.length; i++) {
				var name = values[i];
				if (name != null && name != "") {
					selectedOptions.push({value:name, text:name});
				}
			}
		}
		
		var availableOptions = [];
		
		if (this._groups) {
			for (var i = 0; i < this._groups.length; i++) {
				var item = this._groups[i];
				availableOptions.push({value:item.name, text:item.name});
			}
		}
		if (this._users) {
			for (var i = 0; i < this._users.length; i++) {
				var item = this._users[i];
				availableOptions.push({value:item.name, text:item.name});
			}
		}
		
		this._selWidget = new com.ibm.rational.report.web.core.app.internal.common.SelectionWidget(
			{availableOptions: availableOptions, selectedOptions: selectedOptions,
			 availableItemsTitle: this._availableTitle, selectedItemsTitle: this._selectedTitle});
		this.selectionWidgetContainer.appendChild(this._selWidget.domNode);	
	},
	
	_getAllUsersError: function(error) {
		this._msgFormatter.displayErrorMessage(ServiceabilityMessages.FAILED_TO_RETREIVE_USERS, error);	
	},
	
	_handleSave: function() {
		dojox.data.dom.removeChildren(this.messageArea);
		var selected = this._selWidget.getAllSelected();
		
		this._control.value = "";
		for (var i = 0; i < selected.length; i++) {
			this._control.value += selected[i].value;
			if (i != selected.length-1)
				this._control.value += ",";
		}
	},
	
	getSelected: function() {
		var selected = this._selWidget.getAllSelected();
		
		var value = "";
		for (var i = 0; i < selected.length; i++) {
			value += selected[i].value;
			if (i != selected.length-1)
				value += ",";
		}
		return value;
	},
	
	_done: function() {
		dojox.data.dom.removeChildren(this.messageArea);
		if (this._postServiceExec != null) {
			this._postServiceExec();
		}
	},
	
	close: function() {
		//delete the background div that was added when creating the 2nd dialog.
		this.blockerDiv.parentNode.removeChild(this.blockerDiv);
		this.dialog.close();
	}
	
});

})();